OC.L10N.register(
    "settings",
    {
    "Private" : "私人",
    "Only visible to people matched via phone number integration through Talk on mobile" : "僅對在手機上的 Talk 透過電話號碼整合符合的人們可見",
    "Local" : "本地",
    "Only visible to people on this instance and guests" : "僅對此站台上的人們與訪客可見",
    "Federated" : "已聯盟",
    "Only synchronize to trusted servers" : "僅同步至受信任的伺服器",
    "Published" : "已發佈",
    "Synchronize to trusted servers and the global and public address book" : "同步到受信任的伺服器以及全域與公開的通訊錄",
    "Verify" : "驗證",
    "Verifying …" : "正在驗證……",
    "Unable to change password" : "無法變更密碼",
    "Very weak password" : "密碼強度非常弱",
    "Weak password" : "密碼強度弱",
    "So-so password" : "密碼強度普通",
    "Good password" : "密碼強度佳",
    "Strong password" : "密碼強度極佳",
    "Groups" : "群組",
    "Group list is empty" : "群組列表為空",
    "Unable to retrieve the group list" : "無法擷取群組列表",
    "{actor} added you to group {group}" : "{actor} 將您加入群組 {group}",
    "You added {user} to group {group}" : "您已將 {user} 加入至群組 {group}",
    "{actor} added {user} to group {group}" : "{actor} 將 {user} 加入至群組 {group}",
    "An administrator added you to group {group}" : "管理員已將您新增至群組 {group}",
    "An administrator added {user} to group {group}" : "管理員已將 {user} 新增至群組 {group}",
    "{actor} removed you from group {group}" : "{actor} 將您從 {group} 群組中移除",
    "You removed {user} from group {group}" : "您已從群組 {group} 移除 {user}",
    "{actor} removed {user} from group {group}" : "{actor} 已從群組 {group} 移除 {user}",
    "An administrator removed you from group {group}" : "管理員已將您從 {group} 群組移除",
    "An administrator removed {user} from group {group}" : "管理員已將 {user} 從 {group} 群組移除",
    "Your <strong>group memberships</strong> were modified" : "您的<strong>群組成員資格</strong>已被修改",
    "{actor} changed your password" : "{actor} 變更了您的密碼",
    "You changed your password" : "您已變更您的密碼",
    "Your password was reset by an administrator" : "您的密碼已被管理員重設",
    "Your password was reset" : "您的密碼已重設",
    "{actor} changed your email address" : "{actor} 變更了您的電子郵件地址",
    "You changed your email address" : "您已更改您的電子郵件地址",
    "Your email address was changed by an administrator" : "您的電子郵件已被管理員變更",
    "You created app password \"{token}\"" : "您建立了應用程式密碼「{token}」",
    "An administrator created app password \"{token}\"" : "管理員建立了應用程式密碼「{token}」",
    "You deleted app password \"{token}\"" : "您刪除了應用程式密碼「{token}」",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "您已將應用程式密碼「{token}」重新命名為「{newToken}」",
    "You granted filesystem access to app password \"{token}\"" : "您授予了應用程式密碼「{token}」檔案系統的存取權限",
    "You revoked filesystem access from app password \"{token}\"" : "您撤銷了應用程式密碼「{token}」檔案系統的存取權限",
    "Security" : "安全性",
    "You successfully logged in using two-factor authentication (%1$s)" : "你已成功使用兩步驟驗證進行登入 (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "使用兩步驟驗證登入失敗 (%1$s)",
    "Remote wipe was started on %1$s" : "遠端抹除已開始於 %1$s",
    "Remote wipe has finished on %1$s" : "遠端抹除已結束於 %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的<strong>密碼</strong>或<strong>電子郵件</strong>已修改",
    "Could not remove app." : "無法移除應用程式。",
    "Could not update app." : "無法更新應用程式。",
    "Wrong password" : "密碼錯誤",
    "Unable to change personal password" : "無法變更個人密碼",
    "Saved" : "已儲存",
    "No user supplied" : "未提供使用者",
    "Unable to change password. Password too long." : "變更密碼失敗。密碼太長。",
    "Authentication error" : "認證錯誤",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "請提供管理員還原密碼；否則所有使用者資料將會遺失。",
    "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理員還原密碼。請檢查密碼並再試一次。",
    "Backend does not support password change, but the user's encryption key was updated." : "後端不支援密碼變更，但使用者的加密金鑰已更新。",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "透過應用程式商店或是聯盟式雲端分享來安裝、更新應用程式",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 使用的版本 %1$s 過舊 (%2$s)。請更新您的作業系統，否則如 %3$s 等功能可能無法正常運作。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 是否過舊。請檢查 Nextcloud 的紀錄檔以取得更多資訊。",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "並未載入 PHP OPcache 模組。要得到更好的效能，建議將其載入到您的 PHP 安裝中。",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "已停用 OPcache。要得到更好的效能，建議在您的 PHP 設定中套用 <code>opcache.enable=1</code>。",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache 被設定為移除程式碼註釋。啟用 OPcache 後，必須設定 <code>opcache.save_comments=1</code> 才能讓 Nextcloud 正常運作。",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允許使用 OPcache API。啟用 OPcache 後，強烈建議使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目錄，或是關閉此設定以停用 OPcache API 限制，以避免在 Nextcloud 核心或應用程式升級期間發生錯誤。",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允許使用 OPcache API。強烈建議使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目錄，或是關閉此設定以停用 OPcache API 限制，以避免在 Nextcloud 核心或應用程式升級期間發生錯誤。",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "幾乎超過了 OPcache 鍵的最大數量。為確保幾乎所有指令稿都可以保留在快取中，建議在您的 PHP 設定中的 <code>opcache.max_accelerated_files</code> 套用高於 <code>%s</code> 的值。",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 緩衝區幾乎快滿了。為確保所有指令稿都可以保留在快取中，建議在您的 PHP 設定中的 <code>opcache.memory_consumption</code> 套用高於 <code>%s</code> 的值。",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 內部字串緩衝區幾乎快滿了。為確保可以有效快取重複字串，建議在您的 PHP 設定中的 <code>opcache.interned_strings_buffer</code> 套用高於 <code>%s</code> 的值。",
    "Invalid SMTP password." : "無效的 SMTP 密碼",
    "Email setting test" : "測試郵件設定",
    "Well done, %s!" : "太棒了，%s！",
    "If you received this email, the email configuration seems to be correct." : "如果您收到這封電子郵件，代表電子郵件設定是正確的。",
    "Email could not be sent. Check your mail server log" : "無法傳送郵件。請檢查您的郵件伺服器紀錄檔",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "傳送郵件時發生問題。請檢查您的設定。（錯誤：%s）",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "您必須先設定您的使用者電子郵件，然後才能傳送測試用的電子郵件。前往 %s 進行設定。",
    "Invalid user" : "無效的使用者",
    "Invalid mail address" : "無效的電子郵件地址",
    "Settings saved" : "設定已儲存",
    "Unable to change full name" : "無法變更全名",
    "Unable to change email address" : "無法變更電子郵件地址",
    "Unable to set invalid phone number" : "無法設定無效的電話號碼",
    "Unable to set invalid website" : "無法設定無效的網站",
    "Some account data was invalid" : "某些帳號資料無效",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "為了驗證您的推特帳號，請在推特上發佈下列推文（請確認推文內容沒有斷行）：",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "為了驗證您的網站，請將下列內容存至您網站的根目錄下路徑為「.well-known/CloudIdVerificationCode.txt」的檔案（請確保全文以一行的格式儲存）",
    "%1$s changed your password on %2$s." : "%1$s 在 %2$s 時更改了您的密碼。",
    "Your password on %s was changed." : "你在 %s 的密碼已變更。",
    "Your password on %s was reset by an administrator." : "您在 %s 的密碼已被管理員重設。",
    "Your password on %s was reset." : "您在 %s 的密碼已重設。",
    "Password for %1$s changed on %2$s" : "%1$s 在 %2$s 的密碼已變更",
    "Password changed for %s" : "%s 的密碼已變更",
    "If you did not request this, please contact an administrator." : "如果你未發送此請求 ，請聯絡系統管理員",
    "Your email address on %s was changed." : "您在 %s 的電子郵件地址已變更",
    "Your email address on %s was changed by an administrator." : "您在 %s 的電子郵件地址已被管理員變更",
    "Email address for %1$s changed on %2$s" : "%1$s 的電子郵件地址在 %2$s 變更",
    "Email address changed for %s" : "%s 的電子郵件地址已變更",
    "The new email address is %s" : "新的電子郵件地址為 %s",
    "Your %s account was created" : "您的 %s 帳號已經建立",
    "Welcome aboard" : "歡迎加入",
    "Welcome aboard %s" : "歡迎加入 %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "歡迎使用您的 %s 帳號，您可以新增、保護並分享您的資料。",
    "Your username is: %s" : "您的使用者名稱為：%s",
    "Set your password" : "設定您的密碼",
    "Go to %s" : "前往 %s",
    "Install Client" : "安裝客戶端程式",
    "Logged in user must be a subadmin" : "登入使用者必須為子管理員",
    "Apps" : "應用程式",
    "Settings" : "設定",
    "Personal" : "個人",
    "Administration" : "管理",
    "Additional settings" : "其他設定",
    "Administration privileges" : "管理員權限",
    "Groupware" : "協作應用程式",
    "Overview" : "概覽",
    "Basic settings" : "基本設定",
    "Sharing" : "分享",
    "Personal info" : "個人資訊",
    "Mobile & desktop" : "行動裝置及桌面",
    "Email server" : "電子郵件伺服器",
    "Security & setup warnings" : "安全及設定警告",
    "Background jobs" : "背景工作",
    "Create" : "建立",
    "Change" : "更改",
    "Delete" : "刪除",
    "Reshare" : "重新分享",
    "Unlimited" : "無限制",
    "Verifying" : "正在驗證",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "背景作業正在檢查使用者匯入的 SSL 證書。請稍後再檢查。",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "有一些使用者匯入的 SSL 證書，這些在 Nextcloud 21 不再能運作。它們可以透過命令列執行 \"occ security:certificates:import\" 指令來匯入。它們在資料目錄中的路徑如下所示。",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "找到無效的 LDAP 使用者或群組 UUID。請審閱您在 LDAP 專家設定中的「覆寫 UUID 偵測」設定，並使用「occ ldap:update-uuid」來更新它們。",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "啟用了舊的伺服器端加密格式。我們建議停用它。",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "正在使用 MariaDB 版本「%s」。Nextcloud 21 或更新版本不支援此版本，並需要 MariaDB 10.2 或更新版本。",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本「%s」。Nextcloud 21 或更新版本不支援此版本，並需要 MySQL 8.0 或 MariaDB 10.2 或更新版本。",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL 版本「%s」。Nextcloud 21 或更新版本不支援此版本，並需要 PostgreSQL 9.6 或更新版本。",
    "Profile information" : "個人檔案資訊",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "個人檔案圖片、全名、電子郵件、電話號碼、地址、網站、Twitter、組織、角色、標題、自傳以及您的個人資料是否已啟用",
    "Nextcloud settings" : "Nextcloud 設定",
    "Here you can decide which group can access certain sections of the administration settings." : "您可以在此決定哪些群組可以存取哪些管理設定。",
    "None" : "無",
    "Unable to modify setting" : "無法修改設定",
    "Two-Factor Authentication" : "雙因素驗證",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "可對所有使用者與特定群組強制啟用雙因素驗證。如果他們沒有設定雙因素驗證提供者，那麼他們就會無法登入系統。",
    "Enforce two-factor authentication" : "強制雙因素驗證",
    "Limit to groups" : "限制給特定群組",
    "Enforcement of two-factor authentication can be set for certain groups only." : "強制雙因素驗證可僅為某些群組設定。",
    "Two-factor authentication is enforced for all members of the following groups." : "對以下群組的所有成員強制開啟雙因素驗證。",
    "Enforced groups" : "已強制的群組",
    "Two-factor authentication is not enforced for members of the following groups." : "以下群組的成員不強制開啟雙因素驗證。",
    "Excluded groups" : "排除的群組",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "選取／排除群組時，其使用以下邏輯來確定使用者是否強制啟用雙因素驗證：如果沒有選取群組，雙因素驗證對所有除了排除群組以外的成員啟用。若選取了群組，則雙因素驗證會對所有該群組的成員啟用。如果某個使用者同時位在選取與排除的群組，則被選取的群組優先程度較高，因此會強制啟用雙因素驗證。",
    "Save changes" : "儲存變更",
    "All" : "所有",
    "Limit app usage to groups" : "限制特定群組使用應用程式",
    "No results" : "沒有結果",
    "Update to {version}" : "更新到 {version}",
    "Remove" : "移除",
    "Disable" : "停用",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最低的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最高的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "無法安裝此應用程式，因為無法滿足下列的依賴關係：",
    "View in store" : "在商店中檢視",
    "Visit website" : "造訪網站",
    "Report a bug" : "回報問題",
    "User documentation" : "使用者說明文件",
    "Admin documentation" : "管理員說明文件",
    "Developer documentation" : "開發者說明文件",
    "This app is supported via your current Nextcloud subscription." : "您目前的 Nextcloud 訂閱支援此應用程式。",
    "Supported" : "支援",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "精選應用程式是由社群開發的。它們提供了相當重要的功能，並已準備好在正式環境使用。",
    "Featured" : "精選",
    "Update to {update}" : "更新到 {update}",
    "All apps are up-to-date." : "所有應用程式都是最新的。",
    "Results from other categories" : "其他分類的結果",
    "No apps found for your version" : "沒有找到適合您的版本的應用程式",
    "Disable all" : "全部停用",
    "Enable all" : "全部啟用",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n 個應用程式有可用的更新"],
    "_Update_::_Update all_" : ["更新全部"],
    "Marked for remote wipe" : "標記為可遠端抹除",
    "Device settings" : "裝置設定",
    "Allow filesystem access" : "允許檔案系統的存取",
    "Rename" : "重新命名",
    "Revoke" : "撤銷",
    "Wipe device" : "抹除裝置",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "若尚未開始抹除，則撤銷此權杖可能會無法抹除您的裝置。",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android 版 Google Chrome",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS 應用程式",
    "{productName} Android app" : "{productName} Android 應用程式",
    "{productName} Talk for iOS" : "iOS 版的 {productName} Talk",
    "{productName} Talk for Android" : "Android 版的 {productName} Talk",
    "Sync client - {os}" : "同步客戶端 - {os}",
    "This session" : "此工作階段",
    "Device" : "裝置",
    "Last activity" : "上次活動",
    "Devices & sessions" : "裝置和工作階段",
    "Web, desktop and mobile clients currently logged in to your account." : "目前登入您的帳號的網頁、桌面和行動裝置客戶端。",
    "Do you really want to wipe your data from this device?" : "您真的想要從此裝置抹除您的資料嗎？",
    "Confirm wipe" : "確認抹除",
    "Error while creating device token" : "建立裝置權杖時發生錯誤",
    "Error while updating device token scope" : "更新裝置權杖範圍時發生錯誤",
    "Error while updating device token name" : "更新裝置權杖名稱時發生錯誤",
    "Error while deleting the token" : "刪除權杖時發生錯誤",
    "Error while wiping the device with the token" : "使用權杖抹除裝置時發生錯誤",
    "App name" : "應用程式名稱",
    "Create new app password" : "建立新的應用程式密碼",
    "Use the credentials below to configure your app or device." : "請使用下方的登入資訊來設定您的應用程式或是裝置",
    "For security reasons this password will only be shown once." : "基於安全性考量，這個密碼只會顯示一次",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "Done" : "完成",
    "Show QR code for mobile apps" : "為行動裝置應用程式顯示 QR code",
    "Copied!" : "已複製！",
    "Copy" : "複製",
    "Could not copy app password. Please copy it manually." : "無法複製應用程式密碼。請手動複製。",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "為了讓伺服器正確運作，設定背景工作非常重要。建議使用 Cron 設定。請查閱說明文件以獲得更多資訊。",
    "Last job execution ran {time}. Something seems wrong." : "上次執行作業的時間是 {time}。似乎有些東西不太對勁。",
    "Last job ran {relativeTime}." : "上次工作執行於 {relativeTime}。",
    "Background job did not run yet!" : "背景工作從未執行！",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "每個頁面載入時執行一次任務。使用情境：單使用者站台。",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php 在 webcron 服務中註冊，每五分鐘透過 HTTP 呼叫一次 cron.php。使用情境：非常小的站台（一到五個使用者，取決於使用量）。",
    "Cron (Recommended)" : "Cron（建議）",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件。請查閱 {linkstart}PHP 說明文件{linkend} 以取得更多資訊。",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "使用系統 cron 服務來每五分鐘呼叫一次 cron.php 檔案。建議所有站台使用。",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php 必須由系統使用者「{user}」執行。",
    "Unable to update background job mode" : "無法更新背景工作模式",
    "Profile" : "個人檔案",
    "Enable or disable profile by default for new users." : "預設情況下為新使用者啟用或停用個人檔案",
    "Enable" : "啟用",
    "Unable to update profile default setting" : "無法更新個人檔案預設設定",
    "Server-side encryption" : "伺服器端加密",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "伺服器端加密可以加密所有上傳到此伺服器的檔案，但這會讓檔案操作時間增加，降低效能，請審慎評估後再啟用。",
    "Enable server-side encryption" : "啟用伺服器端加密",
    "Please read carefully before activating server-side encryption:" : "在啟動伺服器端加密前，請先仔細閱讀：",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦啟用加密，從那時開始上傳到伺服器的檔案都會被加密，若日後要停用加密，需要作用中加密模組的支援，而且所有的設定（例如：還原金鑰）都正確。",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "單獨加密不能保證系統安全性。請參考加密應用程式運作原理，及支援的使用案例的文件，以取得更多資訊。",
    "Be aware that encryption always increases the file size." : "請注意，加密一定會增加檔案的大小。",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定時備份您的資料沒有壞處，若您有啟用加密，請確保您也有備份加密金鑰。",
    "This is the final warning: Do you really want to enable encryption?" : "這是最後的警告：請問您真的要開啟加密模式？",
    "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式選單中啟用加密模組",
    "Select default encryption module:" : "選擇預設的加密模組：",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "您必須將您的加密金鑰從舊的加密 (ownCloud <= 8.0) 轉換成新的。請啟用 \"Default encryption module\" 並執行 {command}",
    "Unable to update server side encryption config" : "無法升級伺服器端加密設定",
    "Rename group" : "重新命名群組",
    "Remove group" : "移除群組",
    "You are about to remove the group {group}. The users will NOT be deleted." : "您將要移除群組 {group}。使用者將不會被刪除。",
    "Please confirm the group removal " : "請確認移除群組",
    "Current password" : "目前密碼",
    "New password" : "新密碼",
    "Change password" : "變更密碼",
    "Your profile picture" : "您的個人資料圖片",
    "Upload profile picture" : "上傳個人資料圖片",
    "Choose profile picture from files" : "從檔案中選擇個人檔案圖片",
    "Remove profile picture" : "移除個人資料圖片",
    "png or jpg, max. 20 MB" : "png 或 jpg，最大 20 MB",
    "Picture provided by original account" : "原始帳號提供的圖片",
    "Cancel" : "取消",
    "Set as profile picture" : "設定為個人資料圖片",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "請注意，您的個人資料圖片最常可能需要24小時才能在所有地方更新。",
    "Choose your profile picture" : "選擇您的個人資料圖片",
    "Please select a valid png or jpg file" : "請選取有效的 png 或 jpg 檔案",
    "Error setting profile picture" : "設定個人資料圖片時發生錯誤",
    "Error cropping profile picture" : "裁剪個人資料圖片時發生錯誤",
    "Error saving profile picture" : "儲存個人資料圖片時發生錯誤",
    "Error removing profile picture" : "移除個人資料圖片時發生錯誤",
    "Your biography" : "您的自傳",
    "Details" : "詳細資料",
    "You are a member of the following groups:" : "你是下列群組的成員︰",
    "You are using <strong>{usage}</strong>" : "您已使用 <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "您已使用 <strong>{totalSpace}</strong> 中的 <strong>{usage}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "您的全名",
    "Email options" : "電子郵件選項",
    "Primary email for password reset and notifications" : "用於密碼重設與通知的主要電子郵件地址",
    "Remove primary email" : "移除主要電子郵件地址",
    "Delete email" : "刪除電子郵件地址",
    "Unset as primary email" : "取消設定為主要電子郵件",
    "This address is not confirmed" : "此地址尚未確認",
    "Set as primary email" : "設定為主要電子郵件",
    "Your email address" : "您的電子郵件信箱",
    "Additional email address {index}" : "額外的電子郵件地址 {index}",
    "Unable to delete primary email address" : "無法刪除主要電子郵件地址",
    "Unable to update primary email address" : "無法更新主要電子郵件地址",
    "Unable to add additional email address" : "無法新增額外的電子郵件地址",
    "Unable to update additional email address" : "無法更新額外的電子郵件地址",
    "Unable to delete additional email address" : "無法刪除額外的電子郵件地址",
    "No email address set" : "未設定電子郵件信箱",
    "Additional emails" : "額外的電子郵件",
    "Your headline" : "您的標題",
    "Language" : "語言",
    "Help translate" : "協助翻譯",
    "Unable to update language" : "無法更新語言",
    "No language set" : "未設定語言",
    "Locale" : "地區設定",
    "Week starts on {firstDayOfWeek}" : "一週從 {firstDayOfWeek} 開始",
    "Unable to update locale" : "無法更新語系",
    "No locale set" : "未設定語系",
    "Your location" : "您的位置",
    "Your organisation" : "您的組織",
    "Your phone number" : "您的電話號碼",
    "Edit your Profile visibility" : "編輯您的個人資料能見度",
    "Enable Profile" : "啟用個人檔案",
    "Unable to update profile enabled state" : "無法更新個人檔案啟用狀態",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "將會遵循您個人檔案中「能見度」與「範圍」較嚴格的設定。舉例來說，當「能見度」設定為「對所有人顯示」，而「範圍」設定為「私人」時。將使用「私人」的設定。",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "無法更新 {displayId} 的能見度",
    "Your role" : "您的角色",
    "Your Twitter handle" : "您的 Twitter 帳號",
    "Your website" : "您的網站",
    "No {property} set" : "未設定 {property}",
    "Unable to update {property}" : "無法更新 {property}",
    "Change scope level of {property}, current scope is {scope}" : "變更 {property} 的範圍層級，目前的範圍是 {scope}",
    "Unable to update federation scope of the primary {property}" : "無法更新主要 {property} 的聯盟範圍",
    "Unable to update federation scope of additional {property}" : "無法更新額外 {property} 的聯盟範圍",
    "Add additional email" : "新增額外電子郵件",
    "Add" : "新增",
    "You do not have permissions to see the details of this user" : "您沒有檢視此使用者詳細資料的權限",
    "Add new password" : "新增密碼",
    "Add new email address" : "新增電子郵件",
    "Add user to group" : "新增使用者到群組",
    "Set user as admin for" : "將使用者設定為管理員",
    "Select user quota" : "選取使用者配額",
    "Delete user" : "刪除使用者",
    "Wipe all devices" : "抹除所有裝置",
    "Disable user" : "停用使用者",
    "Enable user" : "啟用使用者",
    "Resend welcome email" : "重新傳送歡迎電子郵件",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "如果遺失裝置或退出組織，這可以從與 {userid} 相關的所有裝置遠端抹除 Nextcloud 資料。僅當裝置連線到網際網路時才有效。",
    "Remote wipe of devices" : "遠端抹除裝置",
    "Wipe {userid}'s devices" : "抹除 {userid} 的裝置",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全刪除 {userid} 的帳號，包含他們所有的個人檔案、應用程式資料等等。",
    "Account deletion" : "帳號刪除",
    "Delete {userid}'s account" : "刪除 {userid} 的帳號",
    "Welcome mail sent!" : "已傳送歡迎郵件！",
    "Edit User" : "編輯使用者",
    "Toggle user actions menu" : "切換使用者動作選單",
    "{size} used" : "已使用 {size}",
    "New user" : "新使用者",
    "Will be autogenerated" : "將自動生成",
    "Display name" : "顯示名稱",
    "Email" : "信箱",
    "Default language" : "預設語言",
    "Add a new user" : "新增使用者",
    "Group admin for" : "群組管理員",
    "Quota" : "容量限制",
    "User backend" : "使用者資料後端",
    "Storage location" : "儲存位址",
    "Last login" : "最後登入",
    "No users in here" : "這裡沒有使用者",
    "Default quota" : "預設儲存容量限制",
    "Common languages" : "常用語言",
    "Other languages" : "其他語言",
    "Password change is disabled because the master key is disabled" : "已停用密碼變更，因為主控金鑰已停用",
    "Passwordless authentication requires a secure connection." : "無密碼身份驗證需要安全連線。",
    "Add WebAuthn device" : "新增 WebAuthn 裝置",
    "Please authorize your WebAuthn device." : "請驗證您的 WebAuthn 裝置。",
    "Name your device" : "請為您的裝置命名",
    "Adding your device …" : "正在新增您的裝置……",
    "Server error while trying to add WebAuthn device" : "嘗試新增 WebAuthn 裝置時發生伺服器錯誤",
    "Server error while trying to complete WebAuthn device registration" : "嘗試完成 WebAuthn 裝置註冊時發生伺服器錯誤。",
    "Unnamed device" : "未命名的裝置",
    "Passwordless Authentication" : "無密碼驗證",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "按照 FIDO2 標準設定您帳號的無密碼驗證",
    "No devices configured." : "未設定裝置。",
    "The following devices are configured for your account:" : "為您的帳號設定了以下裝置。",
    "Your browser does not support WebAuthn." : "您的瀏覽器不支援 WebAuthn。",
    "Your apps" : "您的應用程式",
    "Active apps" : "已啟用應用程式",
    "Disabled apps" : "已停用應用程式",
    "Updates" : "更新",
    "App bundles" : "應用程式套裝",
    "Featured apps" : "精選應用程式",
    "{license}-licensed" : "以 {license} 授權",
    "Changelog" : "變更紀錄",
    "by {author}\n{license}" : "作者為 {author}\n{license}",
    "Enter group name" : "輸入群組名稱",
    "Add group" : "新增群組",
    "Active users" : "活躍使用者",
    "Admins" : "管理者",
    "Disabled users" : "已停用使用者",
    "Default quota:" : "預設容量限制：",
    "Select default quota" : "選取預設容量限制",
    "Show Languages" : "顯示語言",
    "Show last login" : "顯示上次登入時間",
    "Show user backend" : "顯示使用者資料後端",
    "Show storage path" : "顯示儲存路徑",
    "Send email to new user" : "傳送電子郵件給新使用者",
    "Not saved" : "未儲存",
    "Sending…" : "正在傳送……",
    "Email sent" : "電子郵件已寄出",
    "Location" : "路徑",
    "Profile picture" : "個人檔案圖片",
    "About" : "關於",
    "Full name" : "全名",
    "Additional email" : "額外的電子郵件",
    "Headline" : "標題",
    "Organisation" : "組織",
    "Phone number" : "電話號碼",
    "Role" : "角色",
    "Twitter" : "Twitter",
    "Website" : "網站",
    "Profile visibility" : "個人資料能見度",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "無法使用，因為此屬性是核心功能（包括檔案分享和日曆邀請）所必需的。",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "無法使用，因為不允許將使用者的特定資料發佈到查詢伺服器，若您有任何問題，請聯絡您的系統管理員",
    "Show to everyone" : "對所有人顯示",
    "Show to logged in users only" : "僅對已登入的使用者顯示",
    "Hide" : "隱藏",
    "Download and enable" : "下載並啟用",
    "Enable untested app" : "啟用未經測試的應用程式",
    "The app will be downloaded from the App Store" : "將會從應用程式商店下載這個應用程式",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此應用程式未被標記為與您的 Nextcloud 版本相容。如果繼續，您仍可安裝應用程式。但請注意應用程式可能無法正常運作。",
    "Never" : "從不",
    "An error occurred during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "應用程式已啟用但是需要更新。您將會在5秒內被重新導向至更新頁面。",
    "Error: This app cannot be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
    "Administrator documentation" : "管理員說明文件",
    "Documentation" : "說明文件",
    "Forum" : "論壇",
    "Login" : "登入",
    "Plain" : "明文",
    "NT LAN Manager" : "NT LAN 管理程式",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "開啟說明文件",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "設定伺服器可以寄送電子郵件非常重要，使用者通知和密碼重設將會需要。",
    "Send mode" : "傳送模式",
    "Encryption" : "加密",
    "Sendmail mode" : "Sendmail 模式",
    "From address" : "寄件地址",
    "Authentication method" : "認證方式",
    "Authentication required" : "需要認證",
    "Server address" : "伺服器位址",
    "Port" : "連接埠",
    "Credentials" : "憑證",
    "SMTP Username" : "SMTP 使用者名稱",
    "SMTP Password" : "SMTP 密碼",
    "Save" : "儲存",
    "Test and verify email settings" : "測試並驗證電子郵件設定",
    "Send email" : "傳送電子郵件",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "正確設定每樣東西對您的站台的安全性與效能來說非常重要。為了協助您，我們正在進行一些自動檢查。請參閱連結資訊以取得更多資訊。",
    "All checks passed." : "所有檢查皆通過。",
    "There are some errors regarding your setup." : "您的設定有些錯誤。",
    "There are some warnings regarding your setup." : "您的設定有些警告。",
    "Checking for system and security issues." : "檢查系統與安全性問題。",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "請再次確認<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安裝指南 ↗</a>，並在<a href=\"%2$s\">紀錄檔</a>中檢查是否有任何錯誤或警告。",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "透過<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我們的安全性掃描 ↗</a>檢查您 Nextcloud 的安全性。",
    "Version" : "版本",
    "You need to enable the File sharing App." : "您必須啟用檔案分享應用程式。",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "系統管理員可以微調分享行為。請查閱說明文件以獲得更多資訊。",
    "Allow apps to use the Share API" : "允許應用程式使用分享 API",
    "Set default expiration date for shares" : "設定分享的預設到期日",
    "Expire after" : "過期於",
    "day(s)" : "天",
    "Enforce expiration date" : "強制設定到期日",
    "Set default expiration date for shares to other servers" : "設定分享到其他伺服器的預設分享過期日",
    "Allow users to share via link and emails" : "允許使用者透過連結與電子郵件分享",
    "Allow public uploads" : "允許公開上傳",
    "Always ask for a password" : "總是詢問密碼",
    "Enforce password protection" : "強制密碼保護",
    "Exclude groups from password requirements:" : "從密碼要求中排除特定群組：",
    "Set default expiration date" : "設定預設的過期日",
    "Exclude groups from creating link shares:" : "禁止特定群組建立分享連結：",
    "Allow resharing" : "允許轉分享",
    "Allow sharing with groups" : "允許與群組分享",
    "Restrict users to only share with users in their groups" : "限制使用者僅能與他們群組中的其他使用者分享",
    "Exclude groups from sharing" : "禁止特定群組分享檔案",
    "These groups will still be able to receive shares, but not to initiate them." : "這些群組仍然能接受其他人的分享，但是沒有辦法發起分享。",
    "Allow username autocompletion in share dialog" : "在分享對話框中允許使用者名稱自動完成",
    "Allow username autocompletion to users within the same groups" : "允許使用者自動完成在同一個群組中的使用者",
    "Allow username autocompletion to users based on phone number integration" : "允許以電話號碼整合為基礎的使用者名稱自動完成",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "若同時啟用「同一個群組」與「電話號碼整合」的自動完成，則符合其中一項條件就會顯示使用者。",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電子郵件地址時，允許自動完成（忽略缺少的通訊錄相符，以及在同一個群組中的）",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "在公開的檔案連結和上傳頁面顯示免責聲明（僅在檔案列表隱藏的時候才會顯示）",
    "This text will be shown on the public link upload page when the file list is hidden." : "這段文字會在公開檔案上傳頁面檔案列表被隱藏的時候顯示。",
    "Default share permissions" : "預設分享權限",
    "Reasons to use Nextcloud in your organization" : "在您的組織中使用 Nextcloud 的原因",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud 社群{linkclose}開發，{githubopen}原始碼{linkclose}以 {licenseopen}AGPL 授權{linkclose}釋出。",
    "Like our Facebook page" : "到我們的 Facebook 頁面按讚",
    "Follow us on Twitter" : "在 Twitter 上追蹤我們",
    "Follow us on Mastodon" : "在 Mastodon 上追蹤我們",
    "Check out our blog" : "逛逛我們的部落格",
    "Subscribe to our newsletter" : "訂閱我們的電子報",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
    "Use a second factor besides your password to increase security for your account." : "使用密碼以外的第二因素來增強您帳號的安全性。",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方應用程式來連線到 Nextcloud，請確保在啟用雙因素驗證前為每個應用程式設定應用程式密碼。",
    "Migration in progress. Please wait until the migration is finished" : "正在進行遷移。請等候遷移結束",
    "Migration started …" : "開始遷移……",
    "An error occurred while changing your language. Please reload the page and try again." : "變更語言時發生錯誤，請重新整理頁面後重試",
    "An error occurred while changing your locale. Please reload the page and try again." : "變更慣用地區時發生錯誤，請重新整理頁面後重試",
    "Select a profile picture" : "選擇個人檔案圖片",
    "Week starts on {fdow}" : "一週開始於 {fdow}",
    "Couldn't remove app." : "無法移除應用程式。",
    "Couldn't update app." : "無法更新應用程式。",
    "Backend doesn't support password change, but the user's encryption key was updated." : "後端不支援變更密碼，但使用者加密金鑰已更新。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 是否過舊。請檢查 nextcloud 的紀錄檔以取得更多資訊。",
    "You need to set your user email before being able to send test emails." : "您必須先設定您的使用者電子郵件，然後才能傳送測試郵件。",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
    "Set as primary mail" : "設定為主要電子郵件",
    "Change privacy level of email" : "變更電子郵件的隱私等級",
    "All languages" : "全部語言",
    "Everyone" : "所有人",
    "An error occured during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
    "Test email settings" : "測試電子郵件設定",
    "Please read carefully before activating server-side encryption: " : "在您啟動伺服器端加密之前，請仔細閱讀：",
    "Enable encryption" : "啟用加密",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您必須將您的加密金鑰從舊的加密 (ownCloud <= 8.0) 遷移到新的。請啟用「預設加密模組」並執行 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您必須將您的加密金鑰從舊的加密 (ownCloud <= 8.0) 遷移到新的。",
    "Start migration" : "開始遷移",
    "Last job execution ran %s. Something seems wrong." : "上次背景工作執行於 %s。似乎有點問題。",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "從 %s 開始，有一些工作未執行。請考慮增加執行頻率。",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "從 %s 開始，有一些工作未執行。請考慮切換為系統 cron。",
    "Last job ran %s." : "上次背景工作執行於 %s",
    "Background job didn’t run yet!" : "背景工作從未執行！",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "為了讓伺服器正確運作，設定背景工作非常重要。建議使用 \"Cron\" 設定。請查閱說明文件以獲得更多資訊。",
    "Pick background job setting" : "挑選背景工作設定",
    "Recommended" : "建議",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統使用者「%s」執行。",
    "days" : "天",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電子郵件地址時，允許使用者名稱自動完成（忽略缺少的通訊錄相符，以及在同一個群組中的）",
    "Change privacy level of profile picture" : "變更個人資料照片的隱私等級",
    "Upload new" : "上傳新的",
    "Select from Files" : "從雲端檔案選擇",
    "Remove image" : "移除圖片",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "請注意，大頭照最長可能需要24小時才能在所有地方更新。",
    "Choose as profile picture" : "設定為個人資料圖片",
    "You are using <strong>%s</strong>" : "您正在使用 <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您已使用 <strong>%2$s</strong> 中的 <strong>%1$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "變更全名的隱私等級",
    "No display name set" : "未設定顯示名稱",
    "Change privacy level of phone number" : "變更電話號碼的隱私等級",
    "Address" : "地址",
    "Change privacy level of address" : "變更地址的隱私等級",
    "Your postal address" : "您的郵遞地址",
    "Change privacy level of website" : "變更網站的隱私等級",
    "It can take up to 24 hours before the account is displayed as verified." : "帳號在顯示為已驗證前可能需要最多24小時。",
    "Link https://…" : "連結 https://...",
    "Change privacy level of Twitter profile" : "變更 Twitter 個人資料的隱私等級",
    "Twitter handle @…" : "Twitter 使用者名稱 @...",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "幾乎超過了 OPcache 鍵的最大數量。為確保幾乎所有指令稿都可以保留在快取中，建議在您的 PHP 設定中的 <code>opcache.max_accelerated_files</code> 套用高於 <code>%s</code> 的值。",
    "Admin privileges" : "管理員權限",
    "Unable to update biography" : "無法更新自傳",
    "Unable to update full name" : "無法更新全名",
    "No full name set" : "未設定全名",
    "Unable to update headline" : "無法更新標題",
    "Unable to update organisation" : "無法更新組織",
    "Unable to update role" : "無法更新角色",
    "Change scope level of {accountProperty}" : "變更 {accountProperty} 的範圍層級",
    "Unable to update federation scope of the primary {accountProperty}" : "無法更新主要 {accountProperty} 的聯盟範圍",
    "Unable to update federation scope of additional {accountProperty}" : "無法更新額外 {accountProperty} 的聯盟範圍",
    "Avatar" : "大頭照"
},
"nplurals=1; plural=0;");
